# Generated by Django 4.1.5 on 2023-07-13 08:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('server', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='function',
            name='type',
            field=models.TextField(blank=True, default='cmd', null=True),
        ),
    ]
